% -------------------------------------
% Proprit de MatlabPourTous
% MPT_INTERFERENCE interface utilisateur dmontrant l'interfrence de deux ondes sunisodales.
% Compatible : MATLAB2013b
% -------------------------------------------------------------------------
% Actions possibles
% 'mpt_init' - initialise l'interface utilisateur graphique
% 'mpt_omega - dfinit la frquence de la deuxime onde
% 'mpt_phase' - dfinit la phase de la deuxime onde
% 'mpt_rafraichir' - trace la superposition des deux ondes

function MPT_Interference(flag)
% netoyage
clc;

% initialise sans argument
if nargin < 1
    flag = 'mpt_init';
end

switch flag
    case 'mpt_init'
        
        % suppression de la figure appelante s'il existe
        if ~isempty(gcf)
            delete(gcf);                            
        end  
        
        % couleur de la figure
        colorfigure = [185/255 205/255 229/255];
        
        % Dfinition de la premire onde
        % omega1 : vitesse angulaire de la 1ere onde, rad/s
        % T : priode de la 1ere onde, s
        % t : chelle de temps, s
        omega1 = 1;
        T = 2*pi / omega1;
        t = 0:T/30:3*T;
        w1 = sin(omega1*t);
        
        % rapport entre la deuxime onde sur la premire 
        multipl = 1; 
        % rapport de phase par rapport  la priode de la deuxime onde
        phase = 0; 
        
        % cration de la figure principale
        H_fig = figure( 'NumberTitle', 'off', ...
                        'Name', 'Interfrence de deux ondes sunisodales', ...
                        'Color', colorfigure);
                
        % cration de la zone de text "Multiplicateur de frquence"
        uicontrol(H_fig,'Units', 'normalized', ...
                        'Position', [0.05 0.07 0.15 0.05], ...
                        'Style', 'Edit', ...
                        'String', num2str(multipl), ...
                        'Tag', 'omega', ...
                        'CallBack', ('MPT_Interference(''mpt_omega'')'));
        uicontrol(H_fig,'Units', 'normalized', ...
                        'Position', [0.05 0.13 0.15 0.08], ...
                        'Style', 'Text', ...
                        'BackGround', colorfigure, ...
                        'String', 'Multiplicateur de frquence');
        
        % Cration de la zone de text "Phase w_2/T2"
        uicontrol(H_fig, 'Units', 'normalized', ...
                        'Position', [0.3 0.07 0.15 0.05], ...
                        'Style', 'Edit', ...
                        'String', num2str(phase), ...
                        'Tag', 'rapport_phase', ...
                        'CallBack', ('MPT_Interference(''mpt_phase'')'));                                
        uicontrol(H_fig,'Units', 'normalized', ...
                        'Position', [0.3 0.13 0.15 0.08], ...
                        'Style', 'Text', ...
                        'BackGround', colorfigure, ...
                        'String', 'Phase w_2/T2');
        
        % Cration du bouton "Refresh"
        uicontrol(H_fig,'Units', 'normalized', ...
                        'Position', [0.55 0.07 0.15 0.14], ...
                        'Style', 'Pushbutton', ...
                        'String', 'Refresh', ...
                        'BackGround', colorfigure, ...
                        'CallBack', ('MPT_Interference(''mpt_rafraichir'')'));
                    
        % Cration du bouton "Restore"
        uicontrol(H_fig,'Units', 'normalized', ...
                        'Position', [0.8 0.07 0.15 0.14], ...
                        'Style', 'Pushbutton', ...
                        'String', 'Restore', ...
                        'BackGround', colorfigure, ...
                        'CallBack', ('MPT_Interference(''mpt_init'')'));
                    
        % Cration de la legende des ondes d'origines
        uicontrol(H_fig,'Units', 'normalized', ...
                        'Position', [0.8 0.71 0.15 0.14], ...
                        'Style', 'Text', ...
                        'BackGround', colorfigure, ...
                        'String', 'Ondes d''origines, w_1 et w_2');
    
        % Cration de la legende de l'onde rsultant
        uicontrol(H_fig,'Units', 'normalized', ...
                        'Position', [0.8 0.36 0.15 0.14], ...
                        'Style', 'Text', ...
                        'BackGround', colorfigure, ...
                        'String', 'Onde rsultante, w_1 + w_2');
    
        % Cration des axes
        Ha_up = axes('Position', [0.05 0.71 0.65 0.21]);
        plot (t, w1, 'r-');
       
        Ha_down = axes('Position', [0.05 0.36 0.65 0.21]);
        plot (t, w1, 'r-');
        xlabel('Time, S');
        
        % allocation d'espace mmoire
        Mydata = cell (7); 
        Mydata{1} = omega1;
        Mydata{2} = t;
        Mydata{3} = w1;
        Mydata{4} = multipl;
        Mydata{5} = phase;
        Mydata{6} = Ha_up;
        Mydata{7} = Ha_down;
        
        % Enregistrement sur la mmoire de l'interface
        set (gcf, 'UserData', Mydata);
        
        % appeler sur changement de la valeur de omega
    case 'mpt_omega'
        
        % lecture de la valeur de omega
        h_omega = findobj (gcf, 'Tag', 'omega');
        multipl = str2double (get(h_omega, 'String'));
        
        % lecture des donnees contenu sur l'interface
        Mydata = get (gcf, 'UserData');
        omega1 = Mydata{1};
        t = Mydata{2};
        w1 = Mydata{3};
        Ha_up = Mydata{6};
        
        % reprsenter la 2eme courbe
        omega2 = omega1 * multipl;
        w2 = sin (omega2*t);
                
        % affichage de la courbe de w2
        axes (Ha_up);
        plot (t, w1, 'r-', t, w2, 'b--');
        
        % sauvegarde de la nouvelle valeur de multipl
        Mydata{4} = multipl;
        set(gcf, 'UserData', Mydata);
        
        % appeler sur changement de la phase
    case 'mpt_phase'
        
        % Lecture de la valeur phase
        h_phase = findobj (gcf, 'Tag', 'rapport_phase');
        phase = str2double (get(h_phase, 'String'));
        
        % lecture des donnes de l'interface
        Mydata = get (gcf, 'UserData');
        omega1 = Mydata{1};
        t = Mydata{2};
        w1 = Mydata{3};
        multipl = Mydata{4};
        Ha_up = Mydata{6};
        
        % representer la 2eme courbe
        omega2 = omega1 * multipl;
        T2 = 2*pi/omega2;
        delta = phase*T2;
        w2 = sin(omega2*t + delta);       
        
        % reprsentation de la 1ere courbe
        axes (Ha_up);
        plot (t, w1, 'r-', t, w2, 'b--');
        
        % sauvegarde de la nouvelle valeur de phase
        Mydata{5} = phase;
        set(gcf, 'UserData', Mydata);
        
    case 'mpt_rafraichir'
        
        % lecture des donnes de l'interface
        Mydata = get (gcf, 'UserData');
        omega1 = Mydata{1};
        t = Mydata{2};
        w1 = Mydata{3};
        multipl = Mydata{4};        
        phase = Mydata{5};
        Ha_down = Mydata{7};
        
        % reprsentation de la courbe rsultante
        omega2 = omega1 * multipl;
        T2 = 2*pi/omega2;
        delta = phase*T2;
        w2 = sin(omega2*t + delta);
        w = w1 + w2;
        axes (Ha_down);
        plot (t, w, 'b-');
        
end % switch
end % function